program define pcweaks,rclass
syntax varlist, k(real) 
//input: varlist: t variables with n observations for each
//       N by T matrix                 
//       k is the factor number
//output: matrix f,l,e,v

//       Results are called by using r(f),r(l),r(e),r(v)
//       r(f): Common factors
//       r(l): Factor loadings
//       r(e): sum of idiosyncratic terms and individual fixed effects
//       r(v): total variance fraction explained by common factors 

mata:y=st_data(.,tokens("`varlist'"))
mata:x=y' //T by N
mata:x1 = x :/ sqrt(diagonal(variance(x))')
mata:k=`k'
mata:n=cols(x)
mata:t=rows(x)
mata: rc=size1(x,k)
mata: f=J(rc[1,1],rc[1,2],0)
mata: l=J(rc[2,1],rc[2,2],0)
mata: e=J(rc[3,1],rc[3,2],0)
mata: v=J(rc[4,1],rc[4,2],0)
mata: pc(x1,k,f,l,e,v)
mata: z1=pcw(x,f)
mata: z = z1'
mata:st_matrix("f",f)
mata:st_matrix("l",l)
mata:st_matrix("e",e')
mata:st_matrix("v",v)
mata:st_matrix("z",z)

return matrix f=f
return matrix l=l
return matrix e=e
return matrix v=v
return matrix z=z
end



mata:
real matrix size1 (real matrix x,real scalar k)
{  
   real scalar n,t
   real matrix sf,sl,se,sv,s
   n=cols(x)
   t=rows(x) 
  
   if (k!=0)  {
         sf=t,k
sl=n,k
se=t,n
sv=n,1
                   }
       else if (k==0) {
         sf=t,1
sl=n,1
se=t,n
sv=n,1
               }        
 
  s=(sf\sl\se\sv)
  return(s)
}
end


 
mata:
real matrix pc(real matrix x,real scalar k,real matrix f,real matrix l,real matrix e,real matrix v)
{  
   real scalar n,t,tt,nn,n0
   real matrix vx,ve,va,ve1,vv,temp
   
  t = rows(x);
  n = cols(x);
  x1 = x:- mean(x);
  
  if (t>n)  {
        x1=x1'
turn=1
           }
    else if (t<=n ) {
turn=0
    } 
  tt = rows(x1);
  nn = cols(x1);
  
  vx = x1*x1'/nn;
  ve=J(tt,tt,0)
  va=J(tt,1,0)
  ve1=J(tt,tt,0)
  fullsvd(vx,ve,va,ve1)
  
  if (k!=0)  {
     ve = ve[.,1::k];
     f = ve:*sqrt(tt);
     l = x1'f/tt;
     e = f*l';
if (turn==0) {
        e =x-e ;
                } 
if (turn==1) {
       e = x'-e';
       temp = f;
       f = l;
       l = temp;
                } 
    n0 = cols(e); 
    v = J(n0,1,1) - diagonal(variance(e):/variance(x)); 
              }
  
  else if (k==0) {
        
        f = J(tt,1,0);
        l = J(nn,1,0);  
        v = J(nn,1,0);
        e = x;
         }
}
end


mata:
real matrix pcw(real matrix x,real matrix f)
{  
   real scalar n,t
   real matrix xx,be,ff,z
   
  t = rows(x);
  n = cols(x);
  k = cols(f);
  xx = J(t,1,1),f;
  be = invsym(xx'*xx)*xx'*x;
  ff = f*be[2::k+1,.];
  z = x - ff;
return(z) 
  }
end
